@@ -1,3 +1,5 @@
+"""A collection command line arguments."""
+
 
 class Argument:
     """Just a wrapper around :meth:`argparse.ArgumentParser.add_argument`.
@@ -5,10 +7,12 @@ class Argument:
     So, except the ``completer`` keyword argument all positional and keywork
     arguments are the same as :meth:`argparse.ArgumentParser.add_argument`.
 
-    :param completer: see `argcomplete <https://argcomplete.readthedocs.io/en/latest/index.html#specifying-completers>`_
+    :param completer: see `argcomplete <https://argcomplete.readthedocs.io/en\
+        /latest/index.html#specifying-completers>`_
     """
 
     completer = None
+
     def __init__(self, *a, completer=None, **kw):
         self._args = a
         self._kwargs = kw
@@ -21,4 +25,3 @@ class Argument:
             argument.completer = self.completer
 
         return argument
-
